#[non_exhaustive]pub struct AccumulatorWrite {
pub address: Option<String>,
pub accumulator_type: Option<String>,
pub operation: Option<i32>,
pub value_kind: Option<i32>,
pub integer_value: Option<u64>,
pub integer_tuple: Vec<u64>,
pub event_digest_value: Vec<EventDigestEntry>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.address: Option<String>accumulator_type: Option<String>operation: Option<i32>value_kind: Option<i32>integer_value: Option<u64>Set when the accumulator value is an integer (value_kind = INTEGER).
integer_tuple: Vec<u64>Set, with len 2, when the accumulator value is an integer tuple (value_kind = INTEGER_TUPLE).
event_digest_value: Vec<EventDigestEntry>Set when the accumulator value is an event digest list (value_kind = EVENT_DIGEST). Contains a non-empty list of (event_index, digest) pairs representing authenticated event stream entries within a transaction.
Implementations
Sourceimpl AccumulatorWrite
impl AccumulatorWrite
pub const ADDRESS_FIELD: &'static MessageField
pub const ACCUMULATOR_TYPE_FIELD: &'static MessageField
pub const OPERATION_FIELD: &'static MessageField
pub const VALUE_KIND_FIELD: &'static MessageField
pub const INTEGER_VALUE_FIELD: &'static MessageField
pub const INTEGER_TUPLE_FIELD: &'static MessageField
pub const EVENT_DIGEST_VALUE_FIELD: &'static MessageField
Sourceimpl AccumulatorWrite
impl AccumulatorWrite
pub fn path_builder() -> AccumulatorWriteFieldPathBuilder
Sourceimpl AccumulatorWrite
impl AccumulatorWrite
pub const fn const_default() -> Self
Sourcepub fn address_opt_mut(&mut self) -> Option<&mut String>
pub fn address_opt_mut(&mut self) -> Option<&mut String>
Sourcepub fn address_mut(&mut self) -> &mut String
pub fn address_mut(&mut self) -> &mut String
Returns a mutable reference to address.
If the field is unset, it is first initialized with the default value.
Sourcepub fn address_opt(&self) -> Option<&str>
pub fn address_opt(&self) -> Option<&str>
Sourcepub fn set_address<T: Into<String>>(&mut self, field: T)
pub fn set_address<T: Into<String>>(&mut self, field: T)
Sets address with the provided value.
Sourcepub fn with_address<T: Into<String>>(self, field: T) -> Self
pub fn with_address<T: Into<String>>(self, field: T) -> Self
Sets address with the provided value.
Sourcepub fn accumulator_type_opt_mut(&mut self) -> Option<&mut String>
pub fn accumulator_type_opt_mut(&mut self) -> Option<&mut String>
Sourcepub fn accumulator_type_mut(&mut self) -> &mut String
pub fn accumulator_type_mut(&mut self) -> &mut String
Returns a mutable reference to accumulator_type.
If the field is unset, it is first initialized with the default value.
Sourcepub fn accumulator_type_opt(&self) -> Option<&str>
pub fn accumulator_type_opt(&self) -> Option<&str>
Sourcepub fn set_accumulator_type<T: Into<String>>(&mut self, field: T)
pub fn set_accumulator_type<T: Into<String>>(&mut self, field: T)
Sets accumulator_type with the provided value.
Sourcepub fn with_accumulator_type<T: Into<String>>(self, field: T) -> Self
pub fn with_accumulator_type<T: Into<String>>(self, field: T) -> Self
Sets accumulator_type with the provided value.
Sourcepub fn with_operation<T: Into<AccumulatorOperation>>(self, field: T) -> Self
pub fn with_operation<T: Into<AccumulatorOperation>>(self, field: T) -> Self
Sets operation with the provided value.
Sourcepub fn with_value_kind<T: Into<AccumulatorValue>>(self, field: T) -> Self
pub fn with_value_kind<T: Into<AccumulatorValue>>(self, field: T) -> Self
Sets value_kind with the provided value.
Sourcepub fn integer_value_opt_mut(&mut self) -> Option<&mut u64>
pub fn integer_value_opt_mut(&mut self) -> Option<&mut u64>
Sourcepub fn integer_value_mut(&mut self) -> &mut u64
pub fn integer_value_mut(&mut self) -> &mut u64
Returns a mutable reference to integer_value.
If the field is unset, it is first initialized with the default value.
Sourcepub fn integer_value_opt(&self) -> Option<u64>
pub fn integer_value_opt(&self) -> Option<u64>
Sourcepub fn set_integer_value(&mut self, field: u64)
pub fn set_integer_value(&mut self, field: u64)
Sets integer_value with the provided value.
Sourcepub fn with_integer_value(self, field: u64) -> Self
pub fn with_integer_value(self, field: u64) -> Self
Sets integer_value with the provided value.
Sourcepub fn integer_tuple(&self) -> &[u64]
pub fn integer_tuple(&self) -> &[u64]
Returns the value of integer_tuple, or the default value if integer_tuple is unset.
Sourcepub fn integer_tuple_mut(&mut self) -> &mut Vec<u64>
pub fn integer_tuple_mut(&mut self) -> &mut Vec<u64>
Returns a mutable reference to integer_tuple.
If the field is unset, it is first initialized with the default value.
Sourcepub fn set_integer_tuple(&mut self, field: Vec<u64>)
pub fn set_integer_tuple(&mut self, field: Vec<u64>)
Sets integer_tuple with the provided value.
Sourcepub fn with_integer_tuple(self, field: Vec<u64>) -> Self
pub fn with_integer_tuple(self, field: Vec<u64>) -> Self
Sets integer_tuple with the provided value.
Sourcepub fn event_digest_value(&self) -> &[EventDigestEntry]
pub fn event_digest_value(&self) -> &[EventDigestEntry]
Returns the value of event_digest_value, or the default value if event_digest_value is unset.
Sourcepub fn event_digest_value_mut(&mut self) -> &mut Vec<EventDigestEntry>
pub fn event_digest_value_mut(&mut self) -> &mut Vec<EventDigestEntry>
Returns a mutable reference to event_digest_value.
If the field is unset, it is first initialized with the default value.
Sourcepub fn set_event_digest_value(&mut self, field: Vec<EventDigestEntry>)
pub fn set_event_digest_value(&mut self, field: Vec<EventDigestEntry>)
Sets event_digest_value with the provided value.
Sourcepub fn with_event_digest_value(self, field: Vec<EventDigestEntry>) -> Self
pub fn with_event_digest_value(self, field: Vec<EventDigestEntry>) -> Self
Sets event_digest_value with the provided value.
Sourceimpl AccumulatorWrite
impl AccumulatorWrite
Sourcepub fn address(&self) -> &str
pub fn address(&self) -> &str
Returns the value of address, or the default value if address is unset.
Sourcepub fn accumulator_type(&self) -> &str
pub fn accumulator_type(&self) -> &str
Returns the value of accumulator_type, or the default value if accumulator_type is unset.
Sourcepub fn operation(&self) -> AccumulatorOperation
pub fn operation(&self) -> AccumulatorOperation
Returns the enum value of operation, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_operation(&mut self, value: AccumulatorOperation)
pub fn set_operation(&mut self, value: AccumulatorOperation)
Sets operation to the provided enum value.
Sourcepub fn value_kind(&self) -> AccumulatorValue
pub fn value_kind(&self) -> AccumulatorValue
Returns the enum value of value_kind, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_value_kind(&mut self, value: AccumulatorValue)
pub fn set_value_kind(&mut self, value: AccumulatorValue)
Sets value_kind to the provided enum value.
Sourcepub fn integer_value(&self) -> u64
pub fn integer_value(&self) -> u64
Returns the value of integer_value, or the default value if integer_value is unset.