#[non_exhaustive]pub struct EventFilter {
pub terms: Vec<EventTerm>,
}Expand description
DNF filter for events: any term may match, and each term is an AND of signed literals. Sender predicates match all events from matching transactions; emit-module, event-type, and event-stream-head predicates match individual event-space dimensions. An absent filter matches everything. A present filter must have at least one term.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.terms: Vec<EventTerm>Terms are ORed together.
Implementations
Sourceimpl EventFilter
impl EventFilter
pub const TERMS_FIELD: &'static MessageField
Sourceimpl EventFilter
impl EventFilter
pub fn path_builder() -> EventFilterFieldPathBuilder
Sourceimpl EventFilter
impl EventFilter
pub const fn const_default() -> Self
Sourcepub fn terms(&self) -> &[EventTerm]
pub fn terms(&self) -> &[EventTerm]
Returns the value of terms, or the default value if terms is unset.
Sourcepub fn terms_mut(&mut self) -> &mut Vec<EventTerm>
pub fn terms_mut(&mut self) -> &mut Vec<EventTerm>
Returns a mutable reference to terms.
If the field is unset, it is first initialized with the default value.
Sourcepub fn with_terms(self, field: Vec<EventTerm>) -> Self
pub fn with_terms(self, field: Vec<EventTerm>) -> Self
Sets terms with the provided value.
Sourceimpl EventFilter
impl EventFilter
Sourcepub fn any(terms: impl IntoIterator<Item = impl Into<EventTerm>>) -> Self
pub fn any(terms: impl IntoIterator<Item = impl Into<EventTerm>>) -> Self
A filter matching events that satisfy any one of terms
(the terms are ORed together).
Sourcepub fn all(literals: impl IntoIterator<Item = impl Into<EventLiteral>>) -> Self
pub fn all(literals: impl IntoIterator<Item = impl Into<EventLiteral>>) -> Self
A filter with a single term matching events that satisfy every one of
literals.
Sourcepub fn matching(literal: impl Into<EventLiteral>) -> Self
pub fn matching(literal: impl Into<EventLiteral>) -> Self
A filter matching events that satisfy a single literal.