#[non_exhaustive]pub struct EventLiteral {
pub negated: bool,
pub predicate: Option<Predicate>,
}Expand description
One signed event predicate literal: a predicate, optionally negated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.negated: boolWhen true, the literal matches events that the predicate does not match.
predicate: Option<Predicate>The event-index predicate to match.
Implementations
Sourceimpl EventLiteral
impl EventLiteral
pub const NEGATED_FIELD: &'static MessageField
pub const SENDER_FIELD: &'static MessageField
pub const EMIT_MODULE_FIELD: &'static MessageField
pub const EVENT_TYPE_FIELD: &'static MessageField
pub const EVENT_STREAM_HEAD_FIELD: &'static MessageField
Sourceimpl EventLiteral
impl EventLiteral
pub fn path_builder() -> EventLiteralFieldPathBuilder
Sourceimpl EventLiteral
impl EventLiteral
pub const fn const_default() -> Self
Sourcepub fn negated_mut(&mut self) -> &mut bool
pub fn negated_mut(&mut self) -> &mut bool
Returns a mutable reference to negated.
If the field is unset, it is first initialized with the default value.
Sourcepub fn set_negated(&mut self, field: bool)
pub fn set_negated(&mut self, field: bool)
Sets negated with the provided value.
Sourcepub fn with_negated(self, field: bool) -> Self
pub fn with_negated(self, field: bool) -> Self
Sets negated with the provided value.
Sourcepub fn sender(&self) -> &SenderFilter
pub fn sender(&self) -> &SenderFilter
Returns the value of sender, or the default value if sender is unset.
Sourcepub fn sender_opt(&self) -> Option<&SenderFilter>
pub fn sender_opt(&self) -> Option<&SenderFilter>
Sourcepub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>
pub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>
Sourcepub fn sender_mut(&mut self) -> &mut SenderFilter
pub fn sender_mut(&mut self) -> &mut SenderFilter
Returns a mutable reference to sender.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_sender<T: Into<SenderFilter>>(&mut self, field: T)
pub fn set_sender<T: Into<SenderFilter>>(&mut self, field: T)
Sets sender with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_sender<T: Into<SenderFilter>>(self, field: T) -> Self
pub fn with_sender<T: Into<SenderFilter>>(self, field: T) -> Self
Sets sender with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn emit_module(&self) -> &EmitModuleFilter
pub fn emit_module(&self) -> &EmitModuleFilter
Returns the value of emit_module, or the default value if emit_module is unset.
Sourcepub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>
pub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>
Sourcepub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>
pub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>
Sourcepub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter
pub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter
Returns a mutable reference to emit_module.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_emit_module<T: Into<EmitModuleFilter>>(&mut self, field: T)
pub fn set_emit_module<T: Into<EmitModuleFilter>>(&mut self, field: T)
Sets emit_module with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_emit_module<T: Into<EmitModuleFilter>>(self, field: T) -> Self
pub fn with_emit_module<T: Into<EmitModuleFilter>>(self, field: T) -> Self
Sets emit_module with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn event_type(&self) -> &EventTypeFilter
pub fn event_type(&self) -> &EventTypeFilter
Returns the value of event_type, or the default value if event_type is unset.
Sourcepub fn event_type_opt(&self) -> Option<&EventTypeFilter>
pub fn event_type_opt(&self) -> Option<&EventTypeFilter>
Sourcepub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>
pub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>
Sourcepub fn event_type_mut(&mut self) -> &mut EventTypeFilter
pub fn event_type_mut(&mut self) -> &mut EventTypeFilter
Returns a mutable reference to event_type.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_event_type<T: Into<EventTypeFilter>>(&mut self, field: T)
pub fn set_event_type<T: Into<EventTypeFilter>>(&mut self, field: T)
Sets event_type with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_event_type<T: Into<EventTypeFilter>>(self, field: T) -> Self
pub fn with_event_type<T: Into<EventTypeFilter>>(self, field: T) -> Self
Sets event_type with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn event_stream_head(&self) -> &EventStreamHeadFilter
pub fn event_stream_head(&self) -> &EventStreamHeadFilter
Returns the value of event_stream_head, or the default value if event_stream_head is unset.
Sourcepub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>
pub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>
Sourcepub fn event_stream_head_opt_mut(
&mut self,
) -> Option<&mut EventStreamHeadFilter>
pub fn event_stream_head_opt_mut( &mut self, ) -> Option<&mut EventStreamHeadFilter>
Sourcepub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter
pub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter
Returns a mutable reference to event_stream_head.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_event_stream_head<T: Into<EventStreamHeadFilter>>(
&mut self,
field: T,
)
pub fn set_event_stream_head<T: Into<EventStreamHeadFilter>>( &mut self, field: T, )
Sets event_stream_head with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_event_stream_head<T: Into<EventStreamHeadFilter>>(
self,
field: T,
) -> Self
pub fn with_event_stream_head<T: Into<EventStreamHeadFilter>>( self, field: T, ) -> Self
Sets event_stream_head with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourceimpl EventLiteral
impl EventLiteral