#[non_exhaustive]pub struct FundsWithdrawal {
pub amount: Option<u64>,
pub coin_type: Option<String>,
pub source: Option<i32>,
pub funder: Option<String>,
pub allowance: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.amount: Option<u64>coin_type: Option<String>source: Option<i32>funder: Option<String>The address whose balance is debited if source is ALLOWANCE.
allowance: Option<String>ObjectId of the allowance object authorizing the withdrawal if source
is ALLOWANCE.
Implementations
Sourceimpl FundsWithdrawal
impl FundsWithdrawal
pub const AMOUNT_FIELD: &'static MessageField
pub const COIN_TYPE_FIELD: &'static MessageField
pub const SOURCE_FIELD: &'static MessageField
pub const FUNDER_FIELD: &'static MessageField
pub const ALLOWANCE_FIELD: &'static MessageField
Sourceimpl FundsWithdrawal
impl FundsWithdrawal
pub fn path_builder() -> FundsWithdrawalFieldPathBuilder
Sourceimpl FundsWithdrawal
impl FundsWithdrawal
pub const fn const_default() -> Self
Sourcepub fn amount_opt_mut(&mut self) -> Option<&mut u64>
pub fn amount_opt_mut(&mut self) -> Option<&mut u64>
Sourcepub fn amount_mut(&mut self) -> &mut u64
pub fn amount_mut(&mut self) -> &mut u64
Returns a mutable reference to amount.
If the field is unset, it is first initialized with the default value.
Sourcepub fn amount_opt(&self) -> Option<u64>
pub fn amount_opt(&self) -> Option<u64>
Sourcepub fn set_amount(&mut self, field: u64)
pub fn set_amount(&mut self, field: u64)
Sets amount with the provided value.
Sourcepub fn with_amount(self, field: u64) -> Self
pub fn with_amount(self, field: u64) -> Self
Sets amount with the provided value.
Sourcepub fn coin_type_opt_mut(&mut self) -> Option<&mut String>
pub fn coin_type_opt_mut(&mut self) -> Option<&mut String>
Sourcepub fn coin_type_mut(&mut self) -> &mut String
pub fn coin_type_mut(&mut self) -> &mut String
Returns a mutable reference to coin_type.
If the field is unset, it is first initialized with the default value.
Sourcepub fn coin_type_opt(&self) -> Option<&str>
pub fn coin_type_opt(&self) -> Option<&str>
Sourcepub fn set_coin_type<T: Into<String>>(&mut self, field: T)
pub fn set_coin_type<T: Into<String>>(&mut self, field: T)
Sets coin_type with the provided value.
Sourcepub fn with_coin_type<T: Into<String>>(self, field: T) -> Self
pub fn with_coin_type<T: Into<String>>(self, field: T) -> Self
Sets coin_type with the provided value.
Sourcepub fn with_source<T: Into<Source>>(self, field: T) -> Self
pub fn with_source<T: Into<Source>>(self, field: T) -> Self
Sets source with the provided value.
Sourcepub fn funder_opt_mut(&mut self) -> Option<&mut String>
pub fn funder_opt_mut(&mut self) -> Option<&mut String>
Sourcepub fn funder_mut(&mut self) -> &mut String
pub fn funder_mut(&mut self) -> &mut String
Returns a mutable reference to funder.
If the field is unset, it is first initialized with the default value.
Sourcepub fn funder_opt(&self) -> Option<&str>
pub fn funder_opt(&self) -> Option<&str>
Sourcepub fn set_funder<T: Into<String>>(&mut self, field: T)
pub fn set_funder<T: Into<String>>(&mut self, field: T)
Sets funder with the provided value.
Sourcepub fn with_funder<T: Into<String>>(self, field: T) -> Self
pub fn with_funder<T: Into<String>>(self, field: T) -> Self
Sets funder with the provided value.
Sourcepub fn allowance_opt_mut(&mut self) -> Option<&mut String>
pub fn allowance_opt_mut(&mut self) -> Option<&mut String>
Sourcepub fn allowance_mut(&mut self) -> &mut String
pub fn allowance_mut(&mut self) -> &mut String
Returns a mutable reference to allowance.
If the field is unset, it is first initialized with the default value.
Sourcepub fn allowance_opt(&self) -> Option<&str>
pub fn allowance_opt(&self) -> Option<&str>
Sourcepub fn set_allowance<T: Into<String>>(&mut self, field: T)
pub fn set_allowance<T: Into<String>>(&mut self, field: T)
Sets allowance with the provided value.
Sourcepub fn with_allowance<T: Into<String>>(self, field: T) -> Self
pub fn with_allowance<T: Into<String>>(self, field: T) -> Self
Sets allowance with the provided value.
Sourceimpl FundsWithdrawal
impl FundsWithdrawal
Sourcepub fn amount(&self) -> u64
pub fn amount(&self) -> u64
Returns the value of amount, or the default value if amount is unset.
Sourcepub fn coin_type(&self) -> &str
pub fn coin_type(&self) -> &str
Returns the value of coin_type, or the default value if coin_type is unset.
Sourcepub fn source(&self) -> Source
pub fn source(&self) -> Source
Returns the enum value of source, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_source(&mut self, value: Source)
pub fn set_source(&mut self, value: Source)
Sets source to the provided enum value.