#[non_exhaustive]pub struct GetPackageRequest {
pub package_id: Option<String>,
pub selector: Option<Selector>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.package_id: Option<String>Required. The storage_id of any version of the requested package.
When version is not set, the package stored at exactly this id is
returned. When version is set, package_id only identifies the
package’s upgrade lineage (via its original id), and the requested
version within that lineage is returned.
selector: Option<Selector>Optional. Return the package in package_id’s upgrade lineage that
matches one of the following:
version: the package with exactly this version.at_checkpoint: the latest package that existed at or before this checkpoint. Values above the current ledger tip resolve to the latest known version.
If neither is set, the package stored at package_id is returned.
Implementations
Sourceimpl GetPackageRequest
impl GetPackageRequest
pub const PACKAGE_ID_FIELD: &'static MessageField
pub const VERSION_FIELD: &'static MessageField
pub const AT_CHECKPOINT_FIELD: &'static MessageField
Sourceimpl GetPackageRequest
impl GetPackageRequest
pub fn path_builder() -> GetPackageRequestFieldPathBuilder
Sourceimpl GetPackageRequest
impl GetPackageRequest
pub const fn const_default() -> Self
Sourcepub fn package_id_opt_mut(&mut self) -> Option<&mut String>
pub fn package_id_opt_mut(&mut self) -> Option<&mut String>
Sourcepub fn package_id_mut(&mut self) -> &mut String
pub fn package_id_mut(&mut self) -> &mut String
Returns a mutable reference to package_id.
If the field is unset, it is first initialized with the default value.
Sourcepub fn package_id_opt(&self) -> Option<&str>
pub fn package_id_opt(&self) -> Option<&str>
Sourcepub fn set_package_id<T: Into<String>>(&mut self, field: T)
pub fn set_package_id<T: Into<String>>(&mut self, field: T)
Sets package_id with the provided value.
Sourcepub fn with_package_id<T: Into<String>>(self, field: T) -> Self
pub fn with_package_id<T: Into<String>>(self, field: T) -> Self
Sets package_id with the provided value.
Sourcepub fn version(&self) -> u64
pub fn version(&self) -> u64
Returns the value of version, or the default value if version is unset.
Sourcepub fn version_opt(&self) -> Option<u64>
pub fn version_opt(&self) -> Option<u64>
Sourcepub fn version_opt_mut(&mut self) -> Option<&mut u64>
pub fn version_opt_mut(&mut self) -> Option<&mut u64>
Sourcepub fn version_mut(&mut self) -> &mut u64
pub fn version_mut(&mut self) -> &mut u64
Returns a mutable reference to version.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_version(&mut self, field: u64)
pub fn set_version(&mut self, field: u64)
Sets version with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_version(self, field: u64) -> Self
pub fn with_version(self, field: u64) -> Self
Sets version with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn at_checkpoint(&self) -> u64
pub fn at_checkpoint(&self) -> u64
Returns the value of at_checkpoint, or the default value if at_checkpoint is unset.
Sourcepub fn at_checkpoint_opt(&self) -> Option<u64>
pub fn at_checkpoint_opt(&self) -> Option<u64>
Sourcepub fn at_checkpoint_opt_mut(&mut self) -> Option<&mut u64>
pub fn at_checkpoint_opt_mut(&mut self) -> Option<&mut u64>
Sourcepub fn at_checkpoint_mut(&mut self) -> &mut u64
pub fn at_checkpoint_mut(&mut self) -> &mut u64
Returns a mutable reference to at_checkpoint.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_at_checkpoint(&mut self, field: u64)
pub fn set_at_checkpoint(&mut self, field: u64)
Sets at_checkpoint with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_at_checkpoint(self, field: u64) -> Self
pub fn with_at_checkpoint(self, field: u64) -> Self
Sets at_checkpoint with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourceimpl GetPackageRequest
impl GetPackageRequest
Sourcepub fn package_id(&self) -> &str
pub fn package_id(&self) -> &str
Returns the value of package_id, or the default value if package_id is unset.