ListTransactionsRequest

Struct ListTransactionsRequest 

#[non_exhaustive]
pub struct ListTransactionsRequest { pub read_mask: Option<FieldMask>, pub start_checkpoint: Option<u64>, pub end_checkpoint: Option<u64>, pub filter: Option<TransactionFilter>, pub options: Option<QueryOptions>, }
Request message for LedgerService.ListTransactions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
read_mask: Option<FieldMask>

Optional. Mask for specifying which parts of the ExecutedTransaction should be returned.

start_checkpoint: Option<u64>

Optional. Start of the checkpoint range to query (inclusive). Defaults to genesis.

end_checkpoint: Option<u64>

Optional. End of the checkpoint range to query (exclusive). Defaults to the current indexed ledger tip.

filter: Option<TransactionFilter>

Optional. DNF filter over indexed dimensions. If absent, all transactions in the range are returned.

options: Option<QueryOptions>

Optional cursor-bounded query options. If unspecified, reads in ascending order with the default item limit. The server enforces a maximum item limit and silently coerces larger values down to it. To paginate, pass the last received Watermark.cursor as options.after (ascending) or options.before (descending) on the next request.

Implementations

Source

impl ListTransactionsRequest

Source

impl ListTransactionsRequest

pub fn path_builder() -> ListTransactionsRequestFieldPathBuilder

Source

impl ListTransactionsRequest

pub const fn const_default() -> Self

pub fn read_mask_opt_mut(&mut self) -> Option<&mut FieldMask>

If read_mask is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn read_mask_mut(&mut self) -> &mut FieldMask

Returns a mutable reference to read_mask. If the field is unset, it is first initialized with the default value.

pub fn read_mask_opt(&self) -> Option<&FieldMask>

If read_mask is set, returns Some with the value; otherwise returns None.

pub fn set_read_mask<T: Into<FieldMask>>(&mut self, field: T)

Sets read_mask with the provided value.

pub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self

Sets read_mask with the provided value.

pub fn start_checkpoint_opt_mut(&mut self) -> Option<&mut u64>

If start_checkpoint is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn start_checkpoint_mut(&mut self) -> &mut u64

Returns a mutable reference to start_checkpoint. If the field is unset, it is first initialized with the default value.

pub fn start_checkpoint_opt(&self) -> Option<u64>

If start_checkpoint is set, returns Some with the value; otherwise returns None.

pub fn set_start_checkpoint(&mut self, field: u64)

Sets start_checkpoint with the provided value.

pub fn with_start_checkpoint(self, field: u64) -> Self

Sets start_checkpoint with the provided value.

pub fn end_checkpoint_opt_mut(&mut self) -> Option<&mut u64>

If end_checkpoint is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn end_checkpoint_mut(&mut self) -> &mut u64

Returns a mutable reference to end_checkpoint. If the field is unset, it is first initialized with the default value.

pub fn end_checkpoint_opt(&self) -> Option<u64>

If end_checkpoint is set, returns Some with the value; otherwise returns None.

pub fn set_end_checkpoint(&mut self, field: u64)

Sets end_checkpoint with the provided value.

pub fn with_end_checkpoint(self, field: u64) -> Self

Sets end_checkpoint with the provided value.

pub fn filter(&self) -> &TransactionFilter

Returns the value of filter, or the default value if filter is unset.

pub fn filter_opt_mut(&mut self) -> Option<&mut TransactionFilter>

If filter is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn filter_mut(&mut self) -> &mut TransactionFilter

Returns a mutable reference to filter. If the field is unset, it is first initialized with the default value.

pub fn filter_opt(&self) -> Option<&TransactionFilter>

If filter is set, returns Some with the value; otherwise returns None.

pub fn set_filter<T: Into<TransactionFilter>>(&mut self, field: T)

Sets filter with the provided value.

pub fn with_filter<T: Into<TransactionFilter>>(self, field: T) -> Self

Sets filter with the provided value.

pub fn options(&self) -> &QueryOptions

Returns the value of options, or the default value if options is unset.

pub fn options_opt_mut(&mut self) -> Option<&mut QueryOptions>

If options is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn options_mut(&mut self) -> &mut QueryOptions

Returns a mutable reference to options. If the field is unset, it is first initialized with the default value.

pub fn options_opt(&self) -> Option<&QueryOptions>

If options is set, returns Some with the value; otherwise returns None.

pub fn set_options<T: Into<QueryOptions>>(&mut self, field: T)

Sets options with the provided value.

pub fn with_options<T: Into<QueryOptions>>(self, field: T) -> Self

Sets options with the provided value.

Source

impl ListTransactionsRequest

pub fn start_checkpoint(&self) -> u64

Returns the value of start_checkpoint, or the default value if start_checkpoint is unset.

pub fn end_checkpoint(&self) -> u64

Returns the value of end_checkpoint, or the default value if end_checkpoint is unset.