TransactionExpiration

Struct TransactionExpiration 

#[non_exhaustive]
pub struct TransactionExpiration { pub kind: Option<i32>, pub epoch: Option<u64>, pub min_epoch: Option<u64>, pub min_timestamp: Option<Timestamp>, pub max_timestamp: Option<Timestamp>, pub chain: Option<String>, pub nonce: Option<u32>, pub allowed_proposers: Option<AllowedProposers>, }
A TTL for a transaction.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kind: Option<i32>epoch: Option<u64>

Maximum epoch in which a transaction can be executed. The provided maximal epoch must be greater than or equal to the current epoch for a transaction to execute.

min_epoch: Option<u64>

Minimal epoch in which a transaction can be executed. The provided minimal epoch must be less than or equal to the current epoch for a transaction to execute.

min_timestamp: Option<Timestamp>

Minimal UNIX timestamp in which a transaction can be executed. The provided minimal timestamp must be less than or equal to the current clock.

max_timestamp: Option<Timestamp>

Maximum UNIX timestamp in which a transaction can be executed. The provided maximal timestamp must be greater than or equal to the current clock.

chain: Option<String>

ChainId of the network this transaction is intended for in order to prevent cross-chain replay

nonce: Option<u32>

User-provided uniqueness identifier to differentiate otherwise identical transactions

allowed_proposers: Option<AllowedProposers>

The validators allowed to propose this transaction in consensus. Only set when kind is VALIDITY. Leave unset to let any validator propose the transaction.

Implementations

Source

impl TransactionExpiration

Source

impl TransactionExpiration

pub fn path_builder() -> TransactionExpirationFieldPathBuilder

Source

impl TransactionExpiration

pub const fn const_default() -> Self

pub fn with_kind<T: Into<TransactionExpirationKind>>(self, field: T) -> Self

Sets kind with the provided value.

pub fn epoch_opt_mut(&mut self) -> Option<&mut u64>

If epoch is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn epoch_mut(&mut self) -> &mut u64

Returns a mutable reference to epoch. If the field is unset, it is first initialized with the default value.

pub fn epoch_opt(&self) -> Option<u64>

If epoch is set, returns Some with the value; otherwise returns None.

pub fn set_epoch(&mut self, field: u64)

Sets epoch with the provided value.

pub fn with_epoch(self, field: u64) -> Self

Sets epoch with the provided value.

pub fn min_epoch_opt_mut(&mut self) -> Option<&mut u64>

If min_epoch is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn min_epoch_mut(&mut self) -> &mut u64

Returns a mutable reference to min_epoch. If the field is unset, it is first initialized with the default value.

pub fn min_epoch_opt(&self) -> Option<u64>

If min_epoch is set, returns Some with the value; otherwise returns None.

pub fn set_min_epoch(&mut self, field: u64)

Sets min_epoch with the provided value.

pub fn with_min_epoch(self, field: u64) -> Self

Sets min_epoch with the provided value.

pub fn min_timestamp_opt_mut(&mut self) -> Option<&mut Timestamp>

If min_timestamp is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn min_timestamp_mut(&mut self) -> &mut Timestamp

Returns a mutable reference to min_timestamp. If the field is unset, it is first initialized with the default value.

pub fn min_timestamp_opt(&self) -> Option<&Timestamp>

If min_timestamp is set, returns Some with the value; otherwise returns None.

pub fn set_min_timestamp<T: Into<Timestamp>>(&mut self, field: T)

Sets min_timestamp with the provided value.

pub fn with_min_timestamp<T: Into<Timestamp>>(self, field: T) -> Self

Sets min_timestamp with the provided value.

pub fn max_timestamp_opt_mut(&mut self) -> Option<&mut Timestamp>

If max_timestamp is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn max_timestamp_mut(&mut self) -> &mut Timestamp

Returns a mutable reference to max_timestamp. If the field is unset, it is first initialized with the default value.

pub fn max_timestamp_opt(&self) -> Option<&Timestamp>

If max_timestamp is set, returns Some with the value; otherwise returns None.

pub fn set_max_timestamp<T: Into<Timestamp>>(&mut self, field: T)

Sets max_timestamp with the provided value.

pub fn with_max_timestamp<T: Into<Timestamp>>(self, field: T) -> Self

Sets max_timestamp with the provided value.

pub fn chain_opt_mut(&mut self) -> Option<&mut String>

If chain is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn chain_mut(&mut self) -> &mut String

Returns a mutable reference to chain. If the field is unset, it is first initialized with the default value.

pub fn chain_opt(&self) -> Option<&str>

If chain is set, returns Some with the value; otherwise returns None.

pub fn set_chain<T: Into<String>>(&mut self, field: T)

Sets chain with the provided value.

pub fn with_chain<T: Into<String>>(self, field: T) -> Self

Sets chain with the provided value.

pub fn nonce_opt_mut(&mut self) -> Option<&mut u32>

If nonce is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn nonce_mut(&mut self) -> &mut u32

Returns a mutable reference to nonce. If the field is unset, it is first initialized with the default value.

pub fn nonce_opt(&self) -> Option<u32>

If nonce is set, returns Some with the value; otherwise returns None.

pub fn set_nonce(&mut self, field: u32)

Sets nonce with the provided value.

pub fn with_nonce(self, field: u32) -> Self

Sets nonce with the provided value.

pub fn allowed_proposers(&self) -> &AllowedProposers

Returns the value of allowed_proposers, or the default value if allowed_proposers is unset.

pub fn allowed_proposers_opt_mut(&mut self) -> Option<&mut AllowedProposers>

If allowed_proposers is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn allowed_proposers_mut(&mut self) -> &mut AllowedProposers

Returns a mutable reference to allowed_proposers. If the field is unset, it is first initialized with the default value.

pub fn allowed_proposers_opt(&self) -> Option<&AllowedProposers>

If allowed_proposers is set, returns Some with the value; otherwise returns None.

pub fn set_allowed_proposers<T: Into<AllowedProposers>>(&mut self, field: T)

Sets allowed_proposers with the provided value.

pub fn with_allowed_proposers<T: Into<AllowedProposers>>(self, field: T) -> Self

Sets allowed_proposers with the provided value.

Source

impl TransactionExpiration

pub fn kind(&self) -> TransactionExpirationKind

Returns the enum value of kind, or the default if the field is unset or set to an invalid enum value.

pub fn set_kind(&mut self, value: TransactionExpirationKind)

Sets kind to the provided enum value.

pub fn epoch(&self) -> u64

Returns the value of epoch, or the default value if epoch is unset.

pub fn min_epoch(&self) -> u64

Returns the value of min_epoch, or the default value if min_epoch is unset.

pub fn chain(&self) -> &str

Returns the value of chain, or the default value if chain is unset.

pub fn nonce(&self) -> u32

Returns the value of nonce, or the default value if nonce is unset.