#[non_exhaustive]pub struct TransactionLiteral {
pub negated: bool,
pub predicate: Option<Predicate>,
}Expand description
One signed transaction predicate literal: a predicate, optionally negated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.negated: boolWhen true, the literal matches transactions that the predicate does not match.
predicate: Option<Predicate>The transaction-index predicate to match.
Implementations
Sourceimpl TransactionLiteral
impl TransactionLiteral
pub const NEGATED_FIELD: &'static MessageField
pub const SENDER_FIELD: &'static MessageField
pub const AFFECTED_ADDRESS_FIELD: &'static MessageField
pub const AFFECTED_OBJECT_FIELD: &'static MessageField
pub const MOVE_CALL_FIELD: &'static MessageField
pub const EMIT_MODULE_FIELD: &'static MessageField
pub const EVENT_TYPE_FIELD: &'static MessageField
pub const EVENT_STREAM_HEAD_FIELD: &'static MessageField
pub const PACKAGE_WRITE_FIELD: &'static MessageField
Sourceimpl TransactionLiteral
impl TransactionLiteral
pub fn path_builder() -> TransactionLiteralFieldPathBuilder
Sourceimpl TransactionLiteral
impl TransactionLiteral
pub const fn const_default() -> Self
Sourcepub fn negated_mut(&mut self) -> &mut bool
pub fn negated_mut(&mut self) -> &mut bool
Returns a mutable reference to negated.
If the field is unset, it is first initialized with the default value.
Sourcepub fn set_negated(&mut self, field: bool)
pub fn set_negated(&mut self, field: bool)
Sets negated with the provided value.
Sourcepub fn with_negated(self, field: bool) -> Self
pub fn with_negated(self, field: bool) -> Self
Sets negated with the provided value.
Sourcepub fn sender(&self) -> &SenderFilter
pub fn sender(&self) -> &SenderFilter
Returns the value of sender, or the default value if sender is unset.
Sourcepub fn sender_opt(&self) -> Option<&SenderFilter>
pub fn sender_opt(&self) -> Option<&SenderFilter>
Sourcepub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>
pub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>
Sourcepub fn sender_mut(&mut self) -> &mut SenderFilter
pub fn sender_mut(&mut self) -> &mut SenderFilter
Returns a mutable reference to sender.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_sender<T: Into<SenderFilter>>(&mut self, field: T)
pub fn set_sender<T: Into<SenderFilter>>(&mut self, field: T)
Sets sender with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_sender<T: Into<SenderFilter>>(self, field: T) -> Self
pub fn with_sender<T: Into<SenderFilter>>(self, field: T) -> Self
Sets sender with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn affected_address(&self) -> &AffectedAddressFilter
pub fn affected_address(&self) -> &AffectedAddressFilter
Returns the value of affected_address, or the default value if affected_address is unset.
Sourcepub fn affected_address_opt(&self) -> Option<&AffectedAddressFilter>
pub fn affected_address_opt(&self) -> Option<&AffectedAddressFilter>
Sourcepub fn affected_address_opt_mut(&mut self) -> Option<&mut AffectedAddressFilter>
pub fn affected_address_opt_mut(&mut self) -> Option<&mut AffectedAddressFilter>
Sourcepub fn affected_address_mut(&mut self) -> &mut AffectedAddressFilter
pub fn affected_address_mut(&mut self) -> &mut AffectedAddressFilter
Returns a mutable reference to affected_address.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_affected_address<T: Into<AffectedAddressFilter>>(&mut self, field: T)
pub fn set_affected_address<T: Into<AffectedAddressFilter>>(&mut self, field: T)
Sets affected_address with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_affected_address<T: Into<AffectedAddressFilter>>(
self,
field: T,
) -> Self
pub fn with_affected_address<T: Into<AffectedAddressFilter>>( self, field: T, ) -> Self
Sets affected_address with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn affected_object(&self) -> &AffectedObjectFilter
pub fn affected_object(&self) -> &AffectedObjectFilter
Returns the value of affected_object, or the default value if affected_object is unset.
Sourcepub fn affected_object_opt(&self) -> Option<&AffectedObjectFilter>
pub fn affected_object_opt(&self) -> Option<&AffectedObjectFilter>
Sourcepub fn affected_object_opt_mut(&mut self) -> Option<&mut AffectedObjectFilter>
pub fn affected_object_opt_mut(&mut self) -> Option<&mut AffectedObjectFilter>
Sourcepub fn affected_object_mut(&mut self) -> &mut AffectedObjectFilter
pub fn affected_object_mut(&mut self) -> &mut AffectedObjectFilter
Returns a mutable reference to affected_object.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_affected_object<T: Into<AffectedObjectFilter>>(&mut self, field: T)
pub fn set_affected_object<T: Into<AffectedObjectFilter>>(&mut self, field: T)
Sets affected_object with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_affected_object<T: Into<AffectedObjectFilter>>(
self,
field: T,
) -> Self
pub fn with_affected_object<T: Into<AffectedObjectFilter>>( self, field: T, ) -> Self
Sets affected_object with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn move_call(&self) -> &MoveCallFilter
pub fn move_call(&self) -> &MoveCallFilter
Returns the value of move_call, or the default value if move_call is unset.
Sourcepub fn move_call_opt(&self) -> Option<&MoveCallFilter>
pub fn move_call_opt(&self) -> Option<&MoveCallFilter>
Sourcepub fn move_call_opt_mut(&mut self) -> Option<&mut MoveCallFilter>
pub fn move_call_opt_mut(&mut self) -> Option<&mut MoveCallFilter>
Sourcepub fn move_call_mut(&mut self) -> &mut MoveCallFilter
pub fn move_call_mut(&mut self) -> &mut MoveCallFilter
Returns a mutable reference to move_call.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_move_call<T: Into<MoveCallFilter>>(&mut self, field: T)
pub fn set_move_call<T: Into<MoveCallFilter>>(&mut self, field: T)
Sets move_call with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_move_call<T: Into<MoveCallFilter>>(self, field: T) -> Self
pub fn with_move_call<T: Into<MoveCallFilter>>(self, field: T) -> Self
Sets move_call with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn emit_module(&self) -> &EmitModuleFilter
pub fn emit_module(&self) -> &EmitModuleFilter
Returns the value of emit_module, or the default value if emit_module is unset.
Sourcepub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>
pub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>
Sourcepub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>
pub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>
Sourcepub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter
pub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter
Returns a mutable reference to emit_module.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_emit_module<T: Into<EmitModuleFilter>>(&mut self, field: T)
pub fn set_emit_module<T: Into<EmitModuleFilter>>(&mut self, field: T)
Sets emit_module with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_emit_module<T: Into<EmitModuleFilter>>(self, field: T) -> Self
pub fn with_emit_module<T: Into<EmitModuleFilter>>(self, field: T) -> Self
Sets emit_module with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn event_type(&self) -> &EventTypeFilter
pub fn event_type(&self) -> &EventTypeFilter
Returns the value of event_type, or the default value if event_type is unset.
Sourcepub fn event_type_opt(&self) -> Option<&EventTypeFilter>
pub fn event_type_opt(&self) -> Option<&EventTypeFilter>
Sourcepub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>
pub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>
Sourcepub fn event_type_mut(&mut self) -> &mut EventTypeFilter
pub fn event_type_mut(&mut self) -> &mut EventTypeFilter
Returns a mutable reference to event_type.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_event_type<T: Into<EventTypeFilter>>(&mut self, field: T)
pub fn set_event_type<T: Into<EventTypeFilter>>(&mut self, field: T)
Sets event_type with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_event_type<T: Into<EventTypeFilter>>(self, field: T) -> Self
pub fn with_event_type<T: Into<EventTypeFilter>>(self, field: T) -> Self
Sets event_type with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn event_stream_head(&self) -> &EventStreamHeadFilter
pub fn event_stream_head(&self) -> &EventStreamHeadFilter
Returns the value of event_stream_head, or the default value if event_stream_head is unset.
Sourcepub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>
pub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>
Sourcepub fn event_stream_head_opt_mut(
&mut self,
) -> Option<&mut EventStreamHeadFilter>
pub fn event_stream_head_opt_mut( &mut self, ) -> Option<&mut EventStreamHeadFilter>
Sourcepub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter
pub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter
Returns a mutable reference to event_stream_head.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_event_stream_head<T: Into<EventStreamHeadFilter>>(
&mut self,
field: T,
)
pub fn set_event_stream_head<T: Into<EventStreamHeadFilter>>( &mut self, field: T, )
Sets event_stream_head with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_event_stream_head<T: Into<EventStreamHeadFilter>>(
self,
field: T,
) -> Self
pub fn with_event_stream_head<T: Into<EventStreamHeadFilter>>( self, field: T, ) -> Self
Sets event_stream_head with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn package_write(&self) -> &PackageWriteFilter
pub fn package_write(&self) -> &PackageWriteFilter
Returns the value of package_write, or the default value if package_write is unset.
Sourcepub fn package_write_opt(&self) -> Option<&PackageWriteFilter>
pub fn package_write_opt(&self) -> Option<&PackageWriteFilter>
Sourcepub fn package_write_opt_mut(&mut self) -> Option<&mut PackageWriteFilter>
pub fn package_write_opt_mut(&mut self) -> Option<&mut PackageWriteFilter>
Sourcepub fn package_write_mut(&mut self) -> &mut PackageWriteFilter
pub fn package_write_mut(&mut self) -> &mut PackageWriteFilter
Returns a mutable reference to package_write.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_package_write<T: Into<PackageWriteFilter>>(&mut self, field: T)
pub fn set_package_write<T: Into<PackageWriteFilter>>(&mut self, field: T)
Sets package_write with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_package_write<T: Into<PackageWriteFilter>>(self, field: T) -> Self
pub fn with_package_write<T: Into<PackageWriteFilter>>(self, field: T) -> Self
Sets package_write with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.